import { Http, HttpDefaults, HttpRequestOptions, PromiseProgress, TypedEvents } from '@ztimson/utils';
export type ApiEvents = TypedEvents & {
    REQUEST: (request: Promise<any>, options: HttpRequestOptions) => any;
    RESPONSE: (response: any, options: HttpRequestOptions) => any;
    REJECTED: (response: Error, options: HttpRequestOptions) => any;
    TOKEN: (token: string | null) => any;
};
export type Health = {
    status: 'offline' | 'ok' | 'degraded' | 'error';
    actions: HealthStatus;
    ai: HealthStatus;
    database: HealthStatus;
    email: HealthStatus;
    payments: HealthStatus;
    phone: HealthStatus;
    version: string;
    commit: string;
};
export type HealthStatus = 'disabled' | 'ok' | 'warn' | 'error';
export declare class Api extends Http {
    readonly url: string;
    readonly opts: HttpDefaults;
    private emitter;
    private _token;
    get token(): string | null;
    set token(token: string | null);
    constructor(url?: string, opts?: HttpDefaults);
    emit: <K extends string | symbol>(event: K, ...args: Parameters<ApiEvents[K]>) => void;
    off: <K extends string | symbol = string>(event: K, listener: ApiEvents[K]) => void;
    on: <K extends string | symbol = string>(event: K, listener: ApiEvents[K]) => () => void;
    once: <K extends string | symbol = string>(event: K, listener?: ApiEvents[K] | undefined) => Promise<any>;
    healthcheck(): PromiseProgress<Health>;
    request<T>(options: HttpRequestOptions): PromiseProgress<T>;
}
//# sourceMappingURL=api.d.ts.map