import { BehaviorSubject } from 'rxjs';
import { Api } from './api';
import { TypedEmitter, TypedEvents } from '@ztimson/utils';
import { User } from './users';
export type AuthEvents = TypedEvents & {
    USER: (user: User | null) => any;
    LOGIN: (user: User) => any;
    LOGOUT: () => any;
    REGISTER: (user: Partial<User>) => any;
    SESSION_EXPIRED: () => any;
};
export type AuthOptions = {
    loginUi?: string;
    persist?: boolean;
};
export declare class Totp {
    private api;
    constructor(api: Api);
    disable(username: string): import('@ztimson/utils').PromiseProgress<void>;
    enable: (username: string) => import('@ztimson/utils').PromiseProgress<void>;
    reset(username: string): import('@ztimson/utils').PromiseProgress<void>;
    setup(username: string, method?: string, totp?: string): import('@ztimson/utils').PromiseProgress<void>;
}
export declare class Auth extends TypedEmitter<AuthEvents> {
    private readonly opts?;
    private readonly api;
    private readonly storageKey;
    totp: Totp;
    $user: BehaviorSubject<User | null | undefined>;
    get user(): User | null | undefined;
    set user(user: User | null | undefined);
    constructor(api: Api | string, opts?: AuthOptions | undefined);
    knownHost(host?: string): Promise<void>;
    login(username: string, password: string, totp?: string): Promise<User | null>;
    loginRedirect(host?: string): Promise<string>;
    logout(): void;
    register(u: Partial<User> & {
        username: string;
        password: string;
    }): Promise<User>;
    reset(password: string, token?: string): Promise<void>;
    reset(email: string): Promise<void>;
    session(token?: string, set?: boolean): Promise<{
        token: string;
        user: User;
        permissions: string[];
    } | null>;
    updatePassword(username: string, password: string, oldPassword?: string): Promise<void>;
}
//# sourceMappingURL=auth.d.ts.map