import { Api } from './api';
import { Meta } from './core';
import { PromiseProgress, TypedEmitter, TypedEvents, HttpRequestOptions } from '@ztimson/utils';
export type DirMeta = {
    children: (DirMeta | FileMeta)[];
    path: string;
    name: string;
    mime: 'directory';
    size: number;
};
export type FileMeta = Meta & {
    path: string;
    name: string;
    mime: string;
    size: number;
};
export type StorageEvents = TypedEvents & {
    LIST: (path: string, response: DirMeta | FileMeta) => any;
    DELETE: (path: string) => any;
    DOWNLOAD: (path: string, data: Blob) => any;
    OPEN: (path: string) => any;
    UPLOAD: (files: FileMeta[]) => any;
};
export declare class Storage extends TypedEmitter<StorageEvents> {
    readonly api: Api;
    constructor(api: Api | string);
    delete(path: string): Promise<void>;
    list(path: string): Promise<DirMeta | FileMeta>;
    open(path: string, target: false): string;
    open(path: string, target?: '_blank' | '_self'): Window | null;
    mkdir(path: string): Promise<DirMeta>;
    download(path: string, opts?: HttpRequestOptions & {
        'downloadAs'?: string;
    }): PromiseProgress<Blob>;
    upload(files?: File | File[] | null, opts?: string | {
        path?: string;
        accept?: string;
        multiple?: boolean;
    }): PromiseProgress<FileMeta[]>;
}
//# sourceMappingURL=storage.d.ts.map